@@ -462,7 +462,9 @@ class DriverOptions(Options):
         """
         super().__init__()
         self._driver_path = None
+        self._user_data_path = None
         self.ini_path = None
+        self.timeouts = {'implicit': 10000, 'pageLoad': 30000, 'script': 30000}
 
         if read_file:
             self.ini_path = ini_path or str(Path(__file__).parent / 'configs.ini')
@@ -475,14 +477,21 @@ class DriverOptions(Options):
             self._extensions = options_dict.get('extensions', [])
             self._experimental_options = options_dict.get('experimental_options', {})
             self._debugger_address = options_dict.get('debugger_address', None)
-            self.set_window_rect = options_dict.get('set_window_rect', None)
             self.page_load_strategy = options_dict.get('page_load_strategy', 'normal')
 
+            for arg in self._arguments:
+                if arg.startswith('--user-data-dir='):
+                    self.set_paths(user_data_path=arg[16:])
+                    break
+
             self.timeouts = options_dict.get('timeouts', {'implicit': 10, 'pageLoad': 30, 'script': 30})
             self.timeouts['implicit'] *= 1000
             self.timeouts['pageLoad'] *= 1000
             self.timeouts['script'] *= 1000
 
+        if '--no-sandbox' not in self._arguments:
+            self._arguments.append('--no-sandbox')
+
     @property
     def driver_path(self) -> str:
         """chromedriver文件路径"""
@@ -491,7 +500,12 @@ class DriverOptions(Options):
     @property
     def chrome_path(self) -> str:
         """浏览器启动文件路径"""
-        return self.binary_location
+        return self.binary_location or 'chrome'
+
+    @property
+    def user_data_path(self) -> str:
+        """返回用户文件夹路径"""
+        return self._user_data_path
 
     # -------------重写父类方法，实现链式操作-------------
     def add_argument(self, argument) -> 'DriverOptions':
@@ -634,14 +648,14 @@ class DriverOptions(Options):
         :param script: 脚本运行超时时间
         :return: 当前对象
         """
-        timeouts = self._caps.get('timeouts', {'implicit': 10, 'pageLoad': 3000, 'script': 3000})
+        # timeouts = self._caps.get('timeouts', {'implicit': 10, 'pageLoad': 3000, 'script': 3000})
         if implicit is not None:
-            timeouts['implicit'] = implicit
+            self.timeouts['implicit'] = implicit
         if pageLoad is not None:
-            timeouts['pageLoad'] = pageLoad * 1000
+            self.timeouts['pageLoad'] = pageLoad * 1000
         if script is not None:
-            timeouts['script'] = script * 1000
-        self.timeouts = timeouts
+            self.timeouts['script'] = script * 1000
+        # self.timeouts = timeouts
 
         return self
 
@@ -682,7 +696,7 @@ class DriverOptions(Options):
         :param user_agent: user agent文本
         :return: 当前对象
         """
-        return self.set_argument('user-agent', user_agent)
+        return self.set_argument('--user-agent', user_agent)
 
     def set_proxy(self, proxy: str) -> 'DriverOptions':
         """设置代理                    \n
@@ -700,6 +714,8 @@ class DriverOptions(Options):
         :param value: 可接收 'normal', 'eager', 'none'
         :return: 当前对象
         """
+        if value not in ('normal', 'eager', 'none'):
+            raise ValueError("只能选择'normal', 'eager', 'none'。")
         self.page_load_strategy = value.lower()
         return self
 
@@ -722,10 +738,10 @@ class DriverOptions(Options):
         :return: 当前对象
         """
         if driver_path is not None:
-            self._driver_path = driver_path
+            self._driver_path = str(driver_path)
 
         if chrome_path is not None:
-            self.binary_location = chrome_path
+            self.binary_location = str(chrome_path)
 
         if local_port is not None:
             self.debugger_address = '' if local_port == '' else f'127.0.0.1:{local_port}'
@@ -734,13 +750,14 @@ class DriverOptions(Options):
             self.debugger_address = debugger_address
 
         if download_path is not None:
-            self.experimental_options['prefs']['download.default_directory'] = download_path
+            self.experimental_options['prefs']['download.default_directory'] = str(download_path)
 
         if user_data_path is not None:
-            self.set_argument('--user-data-dir', user_data_path)
+            self.set_argument('--user-data-dir', str(user_data_path))
+            self._user_data_path = user_data_path
 
         if cache_path is not None:
-            self.set_argument('--disk-cache-dir', cache_path)
+            self.set_argument('--disk-cache-dir', str(cache_path))
 
         return self
 
