@@ -19,8 +19,13 @@ class ShadowRootElement(BaseElement):
     """ShadowRootElement是用于处理ShadowRoot的类，使用方法和DriverElement基本一致"""
 
     def __init__(self, inner_ele: WebElement, parent_ele: DriverElement):
-        super().__init__(inner_ele, parent_ele.page)
+        super().__init__(parent_ele.page)
         self.parent_ele = parent_ele
+        self._inner_ele = inner_ele
+
+    @property
+    def inner_ele(self) -> WebElement:
+        return self._inner_ele
 
     def __repr__(self) -> str:
         return f'<ShadowRootElement in {self.parent_ele} >'
@@ -177,11 +182,13 @@ class ShadowRootElement(BaseElement):
     def _ele(self,
              loc_or_str: Union[Tuple[str, str], str],
              timeout: float = None,
-             single: bool = True) -> Union[DriverElement, str, None, List[Union[DriverElement, str]]]:
+             single: bool = True,
+             relative: bool = False) -> Union[DriverElement, str, None, List[Union[DriverElement, str]]]:
         """返回当前元素下级符合条件的子元素，默认返回第一个                                                    \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 查找元素超时时间
         :param single: True则返回第一个，False则返回全部
+        :param relative: WebPage用的表示是否相对定位的参数
         :return: DriverElement对象
         """
         # 先转换为sessionElement，再获取所有元素，获取它们的css selector路径，再用路径在页面上执行查找
